==> com.liferay.faces.bridge.impl-3.0.0-sources.jar: com/liferay/faces/bridge/context/internal/ServletContextRichFacesImpl.java <==
/**
 * Copyright (c) 2000-2016 Liferay, Inc. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.liferay.faces.bridge.context.internal;

import java.io.InputStream;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.Enumeration;
import java.util.Set;

import javax.portlet.PortletContext;
import javax.servlet.RequestDispatcher;
import javax.servlet.Servlet;
import javax.servlet.ServletContext;
import javax.servlet.ServletException;


/**
 * This class is part of a workaround for <a href="https://issues.liferay.com/browse/FACES-2638">FACES_2638</a> that
 * provides the renderer for rich:fileUpload with a ServletContext instead of a PortletContext.
 *
 * @author  Neil Griffin
 */
public class ServletContextRichFacesImpl implements ServletContext {

	// Private Data Members
	private PortletContext portletContext;

	public ServletContextRichFacesImpl(PortletContext portletContext) {
		this.portletContext = portletContext;
	}

	// Java 1.6+ @Override
	public Object getAttribute(String name) {
		return portletContext.getAttribute(name);
	}

	// Java 1.6+ @Override
	public Enumeration<String> getAttributeNames() {
		return portletContext.getAttributeNames();
	}

	// Java 1.6+ @Override
	public ServletContext getContext(String uripath) {
		throw new UnsupportedOperationException();
	}

	// Java 1.6+ @Override
	public String getContextPath() {
		throw new UnsupportedOperationException();
	}

	// Java 1.6+ @Override
	public String getInitParameter(String name) {
		return portletContext.getInitParameter(name);
	}

	// Java 1.6+ @Override
	public Enumeration<String> getInitParameterNames() {
		return portletContext.getInitParameterNames();
	}

	// Java 1.6+ @Override
	public int getMajorVersion() {
		throw new UnsupportedOperationException();
	}

	// Java 1.6+ @Override
	public String getMimeType(String file) {
		return portletContext.getMimeType(file);
	}

	// Java 1.6+ @Override
	public int getMinorVersion() {
		throw new UnsupportedOperationException();
	}

	// Java 1.6+ @Override
	public RequestDispatcher getNamedDispatcher(String name) {
		throw new UnsupportedOperationException();
	}

	// Java 1.6+ @Override
	public String getRealPath(String path) {
		return portletContext.getRealPath(path);
	}

	// Java 1.6+ @Override
	public RequestDispatcher getRequestDispatcher(String path) {
		throw new UnsupportedOperationException();
	}

	// Java 1.6+ @Override
	public URL getResource(String path) throws MalformedURLException {
		return portletContext.getResource(path);
	}

	// Java 1.6+ @Override
	public InputStream getResourceAsStream(String path) {
		return portletContext.getResourceAsStream(path);
	}

	// Java 1.6+ @Override
	public Set<String> getResourcePaths(String path) {
		return portletContext.getResourcePaths(path);
	}

	// Java 1.6+ @Override
	public String getServerInfo() {
		return portletContext.getServerInfo();
	}

	// Java 1.6+ @Override
	public Servlet getServlet(String name) throws ServletException {
		throw new UnsupportedOperationException();
	}

	// Java 1.6+ @Override
	public String getServletContextName() {
		return portletContext.getPortletContextName();
	}

	// Java 1.6+ @Override
	public Enumeration<String> getServletNames() {
		throw new UnsupportedOperationException();
	}

	// Java 1.6+ @Override
	public Enumeration<Servlet> getServlets() {
		throw new UnsupportedOperationException();
	}

	// Java 1.6+ @Override
	public void log(String msg) {
		portletContext.log(msg);
	}

	// Java 1.6+ @Override
	public void log(Exception exception, String message) {
		portletContext.log(message, exception);
	}

	// Java 1.6+ @Override
	public void log(String message, Throwable throwable) {
		portletContext.log(message, throwable);
	}

	// Java 1.6+ @Override
	public void removeAttribute(String name) {
		portletContext.removeAttribute(name);
	}

	// Java 1.6+ @Override
	public void setAttribute(String name, Object object) {
		portletContext.setAttribute(name, object);
	}
}

==> com.liferay.faces.bridge.impl-4.0.0-sources.jar: com/liferay/faces/bridge/context/internal/ServletContextRichFacesImpl.java <==
/**
 * Copyright (c) 2000-2016 Liferay, Inc. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.liferay.faces.bridge.context.internal;

import java.io.InputStream;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.Enumeration;
import java.util.EventListener;
import java.util.Map;
import java.util.Set;

import javax.portlet.PortletContext;
import javax.servlet.Filter;
import javax.servlet.FilterRegistration;
import javax.servlet.RequestDispatcher;
import javax.servlet.Servlet;
import javax.servlet.ServletContext;
import javax.servlet.ServletException;
import javax.servlet.ServletRegistration;
import javax.servlet.SessionCookieConfig;
import javax.servlet.SessionTrackingMode;
import javax.servlet.descriptor.JspConfigDescriptor;


/**
 * This class is part of a workaround for <a href="https://issues.liferay.com/browse/FACES-2638">FACES_2638</a> that
 * provides the renderer for rich:fileUpload with a ServletContext instead of a PortletContext.
 *
 * @author  Neil Griffin
 */
public class ServletContextRichFacesImpl implements ServletContext {

	// Private Data Members
	private PortletContext portletContext;

	public ServletContextRichFacesImpl(PortletContext portletContext) {
		this.portletContext = portletContext;
	}

	@Override
	public FilterRegistration.Dynamic addFilter(String filterName, String className) {
		throw new UnsupportedOperationException();
	}

	@Override
	public FilterRegistration.Dynamic addFilter(String filterName, Filter filter) {
		throw new UnsupportedOperationException();
	}

	@Override
	public FilterRegistration.Dynamic addFilter(String filterName, Class<? extends Filter> filterClass) {
		throw new UnsupportedOperationException();
	}

	@Override
	public void addListener(String className) {
		throw new UnsupportedOperationException();
	}

	@Override
	public <T extends EventListener> void addListener(T t) {
		throw new UnsupportedOperationException();
	}

	@Override
	public void addListener(Class<? extends EventListener> listenerClass) {
		throw new UnsupportedOperationException();
	}

	@Override
	public ServletRegistration.Dynamic addServlet(String servletName, String className) {
		throw new UnsupportedOperationException();
	}

	@Override
	public ServletRegistration.Dynamic addServlet(String servletName, Servlet servlet) {
		throw new UnsupportedOperationException();
	}

	@Override
	public ServletRegistration.Dynamic addServlet(String servletName, Class<? extends Servlet> servletClass) {
		throw new UnsupportedOperationException();
	}

	@Override
	public <T extends Filter> T createFilter(Class<T> clazz) throws ServletException {
		throw new UnsupportedOperationException();
	}

	@Override
	public <T extends EventListener> T createListener(Class<T> clazz) throws ServletException {
		throw new UnsupportedOperationException();
	}

	@Override
	public <T extends Servlet> T createServlet(Class<T> clazz) throws ServletException {
		throw new UnsupportedOperationException();
	}

	@Override
	public void declareRoles(String... roleNames) {
		throw new UnsupportedOperationException();
	}

	@Override
	public Object getAttribute(String name) {
		return portletContext.getAttribute(name);
	}

	@Override
	public Enumeration<String> getAttributeNames() {
		return portletContext.getAttributeNames();
	}

	@Override
	public ClassLoader getClassLoader() {
		throw new UnsupportedOperationException();
	}

	@Override
	public ServletContext getContext(String uripath) {
		throw new UnsupportedOperationException();
	}

	@Override
	public String getContextPath() {
		throw new UnsupportedOperationException();
	}

	@Override
	public Set<SessionTrackingMode> getDefaultSessionTrackingModes() {
		throw new UnsupportedOperationException();
	}

	@Override
	public int getEffectiveMajorVersion() {
		throw new UnsupportedOperationException();
	}

	@Override
	public int getEffectiveMinorVersion() {
		throw new UnsupportedOperationException();
	}

	@Override
	public Set<SessionTrackingMode> getEffectiveSessionTrackingModes() {
		throw new UnsupportedOperationException();
	}

	@Override
	public FilterRegistration getFilterRegistration(String filterName) {
		throw new UnsupportedOperationException();
	}

	@Override
	public Map<String, ? extends FilterRegistration> getFilterRegistrations() {
		throw new UnsupportedOperationException();
	}

	@Override
	public String getInitParameter(String name) {
		return portletContext.getInitParameter(name);
	}

	@Override
	public Enumeration<String> getInitParameterNames() {
		return portletContext.getInitParameterNames();
	}

	@Override
	public JspConfigDescriptor getJspConfigDescriptor() {
		throw new UnsupportedOperationException();
	}

	@Override
	public int getMajorVersion() {
		throw new UnsupportedOperationException();
	}

	@Override
	public String getMimeType(String file) {
		return portletContext.getMimeType(file);
	}

	@Override
	public int getMinorVersion() {
		throw new UnsupportedOperationException();
	}

	@Override
	public RequestDispatcher getNamedDispatcher(String name) {
		throw new UnsupportedOperationException();
	}

	@Override
	public String getRealPath(String path) {
		return portletContext.getRealPath(path);
	}

	@Override
	public RequestDispatcher getRequestDispatcher(String path) {
		throw new UnsupportedOperationException();
	}

	@Override
	public URL getResource(String path) throws MalformedURLException {
		return portletContext.getResource(path);
	}

	@Override
	public InputStream getResourceAsStream(String path) {
		return portletContext.getResourceAsStream(path);
	}

	@Override
	public Set<String> getResourcePaths(String path) {
		return portletContext.getResourcePaths(path);
	}

	@Override
	public String getServerInfo() {
		return portletContext.getServerInfo();
	}

	@Override
	public Servlet getServlet(String name) throws ServletException {
		throw new UnsupportedOperationException();
	}

	@Override
	public String getServletContextName() {
		return portletContext.getPortletContextName();
	}

	@Override
	public Enumeration<String> getServletNames() {
		throw new UnsupportedOperationException();
	}

	@Override
	public ServletRegistration getServletRegistration(String servletName) {
		throw new UnsupportedOperationException();
	}

	@Override
	public Map<String, ? extends ServletRegistration> getServletRegistrations() {
		throw new UnsupportedOperationException();
	}

	@Override
	public Enumeration<Servlet> getServlets() {
		throw new UnsupportedOperationException();
	}

	@Override
	public SessionCookieConfig getSessionCookieConfig() {
		throw new UnsupportedOperationException();
	}

	@Override
	public void log(String msg) {
		portletContext.log(msg);
	}

	@Override
	public void log(Exception exception, String message) {
		portletContext.log(message, exception);
	}

	@Override
	public void log(String message, Throwable throwable) {
		portletContext.log(message, throwable);
	}

	@Override
	public void removeAttribute(String name) {
		portletContext.removeAttribute(name);
	}

	@Override
	public void setAttribute(String name, Object object) {
		portletContext.setAttribute(name, object);
	}

	@Override
	public boolean setInitParameter(String name, String value) {
		return false;
	}

	@Override
	public void setSessionTrackingModes(Set<SessionTrackingMode> sessionTrackingModes) {
		throw new UnsupportedOperationException();
	}
}
